/*
 * Copyright (c) 2009, Peter Abeles. All Rights Reserved.
 *
 * This file is part of Efficient Java Matrix Library (EJML).
 *
 * EJML is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *
 * EJML is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with EJML.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.ejml.alg.dense.decomposition;

import org.ejml.data.DenseMatrix64F;


/**
 * <p>
 * LU Decomposition refactors the original matrix such that:<br>
 * <div align=center> L*U = A</div>
 * where L is a lower triangular matrix, U is an upper triangular matrix and A is
 * the original matrix.
 * </p>
 *
 * <p>
 * LU Decompositon is usefull since once the decomposition has been performed linear
 * equations can be quickly solved and the original matrix A inverted.  Different algorithms
 * can be selected to perform the decomposition, all will have the same end result.
 * </p>
 * <p>
 * To use this class first specify the size of the matrixs that will be decomposed by it in
 * the constructor.  Only square m by m matrices can be decomposed.  Then to decompose a matrix
 * call {@link #decompose}.  If it encounters any problems an exception will be thrown.  After
 * that all the other functiosn will be available for solving and inverting matrices.
 * </p>
 *
 * @author Peter Abeles
 */
public interface LUDecomposition extends DecompositionInterface {

    public void setToLower( DenseMatrix64F lower );

    public void setToUpper( DenseMatrix64F upper );

    /**
     * Computes the LU decompsotion.
     *
     * @param orig The matrix which is being decomposed.  Not modified.
     * @return Returns if it was able to decompose the matrix.
     */
    public boolean decompose( DenseMatrix64F orig );

    public boolean isSingular();

    public double computeDeterminant();
}
